// ============================================================================
// Project:	Deductive Database
// Filename:	tok.h
// Purpose:	Token types
// Last Change:	06.10.2016
// Language:	C++
// EMail:	brass@informatik.uni-halle.de
// WWW:		http://www.informatik.uni-halle.de/~brass/
// Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
// Copyright:	(c) 1998-2016 by Stefan Brass
// License:	See file "LICENSE" for copying conditions.
// Note:	There is no warranty at all - this code may contain bugs.
// ============================================================================


//=============================================================================
// Include File Frame:
//=============================================================================

#ifndef	TOK_INCLUDED
#define TOK_INCLUDED

//=============================================================================
// Used Types and Macros:
//=============================================================================

#ifndef VER_INCLUDED
#include "ver.h"
#endif

#ifndef STR_INCLUDED
#include "str.h"
#endif

#ifndef CHECK_INCLUDED
#include "check.h"
#endif

//=============================================================================
// Exported Types:
//=============================================================================

//-----------------------------------------------------------------------------
// tok_t: Token types.
//-----------------------------------------------------------------------------

typedef enum {
	TOK_EOF,
	TOK_FULLSTOP,
	TOK_ATOM,
	TOK_STR,
	TOK_INT,
	TOK_VAR,
	TOK_ANONVAR,
	TOK_COMMA,
	TOK_LPAREN,
	TOK_RPAREN,
	TOK_IF,
	TOK_AND,
	TOK_OR,
	TOK_NOT,
	TOK_QUERY,
	TOK_COLON,
	TOK_LESS,
	TOK_GREATER,
	TOK_MINUS,
	TOK_ILLEGAL_CHAR,
	TOK_MISSINGQ,
	TOK_NOSPACE,
	TOK_INT_OVERFLOW,
	TOK_BAD_ESCAPE_SEQ
} tok_t;

//=============================================================================
// Exported Functions:
//=============================================================================

//-----------------------------------------------------------------------------
// tok_valid: Is the parameter a valid element of the enumeration type?
//-----------------------------------------------------------------------------

#ifdef	VER_DEBUG
bool	tok_valid(tok_t tok);
#endif

//-----------------------------------------------------------------------------
// tok_name: Name of token type.
//-----------------------------------------------------------------------------

str_t	tok_name(tok_t tok);

//-----------------------------------------------------------------------------
// tok_is_err: The token type marks a lexical error.
//-----------------------------------------------------------------------------

inline bool	tok_is_err(tok_t tok)
{
	return (tok == TOK_ILLEGAL_CHAR ||
			tok == TOK_MISSINGQ ||
			tok == TOK_NOSPACE ||
			tok == TOK_INT_OVERFLOW ||
			tok == TOK_BAD_ESCAPE_SEQ);
}

//=============================================================================
// End of File:
//=============================================================================

#endif

